@@ -1,4 +1,3 @@
-
 ## -----------------------------------------------------------------------
 ## utility functions exposed to the users
 ## -----------------------------------------------------------------------
@@ -29,7 +28,7 @@ is.db.data.frame <- function (x)
         valid[[i]] <- y[y[,id]>tick[i] & y[,id]<=tick[i+1],-id]
         train[[i]] <- y[!(y[,id]>tick[i] & y[,id]<=tick[i+1]),-id]
     }
-    
+
     list(train = train, valid = valid, inter = y, dist.by = y@.dist.by)
 }
 
@@ -49,7 +48,7 @@ is.db.data.frame <- function (x)
 ## restore all warning levels
 .restore.warnings <- function (pre.warn)
 {
-    msg.level <- .set.msg.level(pre.warn$msg.level, pre.warn$conn.id) 
+    msg.level <- .set.msg.level(pre.warn$msg.level, pre.warn$conn.id)
     options(warn = pre.warn$warn.r) # reset R warning level
 }
 
@@ -60,7 +59,7 @@ is.db.data.frame <- function (x)
 .get.package.path <- function ()
 {
     version <- .localVars$R.ver
-    if (version != R.version.string && as.numeric(version) < 2.13) 
+    if (version != R.version.string && as.numeric(version) < 2.13)
         eval(parse(text = paste(".path.package(\"", .this.pkg.name, "\")",
                    sep = "")))
     else
@@ -130,7 +129,7 @@ is.db.data.frame <- function (x)
         y
     } else {
         regmatches(x, m, invert)
-    }    
+    }
 }
 
 ## ----------------------------------------------------------------------
@@ -157,8 +156,8 @@ is.db.data.frame <- function (x)
         table.schema <- table[1]
     } else {
         schemas <- arraydb.to.arrayr(
-            .get.res(sql="select current_schemas(True)",
-                     conn.id=conn.id, warns=NULL),
+            db.q("select current_schemas(True)",
+                 conn.id=conn.id, verbose = FALSE),
             type = "character")
         table_schema <- character(0)
         for (schema in schemas)
